<?php

/**
 * @file
 * Utility code related to base themes.
 *
 * The concepts/wording in this file are inspired by (ie, stolen from) the D7
 * Omega base theme.
 */

/**
 * Implements hook_preprocess_page().
 */
function ui_suite_uswds_preprocess_page(&$variables) {

  $current_route = \Drupal::routeMatch()->getRouteName();

  if ($current_route === 'ui_patterns.patterns.overview') {
    $variables['#attached']['library'][] = 'ui_suite_uswds/ui_pattern_library_overrides';
  }

  // Provide the agency information for the footer.
  $variables['display_footer_agency'] = theme_get_setting('uswds_footer_agency');
  $footer_variables = [
    'footer_agency_name',
    'footer_agency_url',
    'footer_agency_logo',
    'contact_center',
    'phone',
    'email',
  ];
  foreach ($footer_variables as $footer_variable) {
    $variables[$footer_variable] = theme_get_setting('uswds_' . $footer_variable);
  }

  $footer_social_links = [
    'facebook' => theme_get_setting('uswds_facebook'),
    'instagram' => theme_get_setting('uswds_instagram'),
    'linkedin' => theme_get_setting('uswds_linkedin'),
    'twitter' => theme_get_setting('uswds_twitter'),
    'youtube' => theme_get_setting('uswds_youtube'),
    'rss_feed' => theme_get_setting('uswds_rss'),
  ];

  $empty = implode("", $footer_social_links);
  if (empty($empty)) {
    $variables['footer_social_links'] = '';
  }
  else {
    $variables['footer_social_links'] = $footer_social_links;
  }

  // Fix the footer logo path.
  if ($variables['footer_agency_logo']) {
    $variables['footer_agency_logo'] = base_path() . ui_suite_uswds_theme_trail_file($variables['footer_agency_logo']);
  }

  // Decide on the type of header.
  $header_style = theme_get_setting('uswds_header_style');
  if (empty($header_style)) {
    $header_style = 'extended';
  }
  $variables['header_style'] = 'usa-header--' . $header_style;
  $variables['header_classes'] = 'usa-header ' . $variables['header_style'];
  if (theme_get_setting('uswds_header_mega')) {
    $variables['header_classes'] .= ' ' . $variables['header_style'] . '-megamenu';
  }
  // And some helpful flags for the header.
  $variables['header_basic'] = ('usa-header--basic' == $variables['header_style']);
  $variables['header_extended'] = ('usa-header--extended' == $variables['header_style']);

  // Hide the secondary menu if using the basic header.
  if ($variables['header_basic']) {
    $variables['page']['secondary_menu'] = FALSE;
  }

  // Show the official U.S. Government banner?
  if (theme_get_setting('uswds_government_banner')) {
    $variables['government_banner'] = [
      '#theme' => 'government_banner',
      '#image_base' => $variables['active_theme_path'] . '/package/dist/img',
    ];
  }

  $variables['footer_classes'] = 'usa-footer usa-footer--big';

  // Add some helpful flags for the footer.
  $variables['footer_agency_heading_class'] = 'usa-footer-logo-heading';
  $variables['footer_agency_logo_class'] = 'usa-footer-logo-img';

  // Whether to display the primary footer section.
  $display_primary_footer = (!empty($variables['page']['footer_primary']));
  $display_primary_footer |= $variables['email'] || $variables['phone'];
  $variables['display_footer_primary'] = $display_primary_footer;

  // Whether to display the secondary footer section.
  $display_secondary_footer = !empty($variables['page']['footer_secondary']);
  $display_secondary_footer |= $variables['display_footer_agency'];
  $variables['display_footer_secondary'] = $display_secondary_footer;

  // Provide this variable so that additional classes can be added to the main
  // section, similar to the header and footer.
  $variables['main_classes'] = '';
}

/**
 * Gets the full theme trail, from active to top-level base.
 *
 * @return array
 *   An array of all themes in the trail, ordered from active to top-level base.
 */
function ui_suite_uswds_theme_trail() {
  $theme = \Drupal::theme()->getActiveTheme();
  $all = [$theme->getName() => $theme] + $theme->getBaseThemeExtensions();
  // This gives us a complete lineage of themes, but we actually only care about
  // the USWDS Base theme and any child themes.
  $trail = [];
  foreach ($all as $key => $value) {
    $trail[$key] = $value;
    if ('ui_suite_uswds' == $key) {
      break;
    }
  }
  return $trail;
}

/**
 * Finds the first occurrence of a given file in the theme trail.
 *
 * @param string $file
 *   The relative path to a file.
 *
 * @return string
 *   The path to the file. If the file does not exist at all, it will simply
 *   return the path of the file as it would be if it existed in the given theme
 *   directly. This ensures that the code that uses this function does not break
 *   if a file does not exist anywhere.
 */
function ui_suite_uswds_theme_trail_file($file) {
  $trail = ui_suite_uswds_theme_trail();
  foreach ($trail as $theme) {
    $current = $theme->getPath() . '/' . $file;
    if (file_exists($current)) {
      return $current;
    }
  }
  // The default (fallback) path is the path of the active theme, even if it
  // does not actually have that file.
  $active = array_shift($trail);
  return $active->getPath() . '/' . $file;
}
