<?php

/**
 * @file
 * Utility code related to menus and menu blocks.
 */

use Drupal\block\Entity\Block;

/**
 * Implements hook_theme_suggestions_HOOK_alter().
 */
function ui_suite_uswds_theme_suggestions_block_alter(array &$suggestions, array $variables) {
  // Set the block variable.
  $block = '';
  if (!empty($variables['elements']['#id'])) {
    $block = Block::load($variables['elements']['#id']);
  }

  if (!empty($block)) {
    // We need to suggest our custom theming for menu blocks in certain regions.
    if (in_array('block__system_menu_block', $suggestions)) {
      $menu_regions =
        [
          'primary_menu',
          'secondary_menu',
          'mobile_menu',
          'sidebar_first',
          'sidebar_second',
          'footer_primary',
          'footer_secondary',
        ];
      if (in_array($block->getRegion(), $menu_regions)) {
        if (_ui_suite_uswds_process_menu_region($block->getRegion())) {
          $suggestions[] = 'block__system_menu_block__' . $block->getRegion();
        }
      }
    }

    // We need to suggest our custom theming for menu blocks in certain regions.
    if (in_array('block__block_content', $suggestions)) {
      $bc_regions = ['hero'];
      if (in_array($block->getRegion(), $bc_regions)) {
        $suggestions[] = 'block__block_content__' . $block->getRegion();
      }
    }
  }
  return $suggestions;
}

/**
 * Implements hook_preprocess_block__DELTA__REGION().
 *
 * This made possible by our custom theme suggestion.
 *
 * @see ui_suite_uswds_theme_suggestions_block_alter()
 */
function ui_suite_uswds_preprocess_block__block_content__hero(&$variables) {
  _ui_suite_uswds_mark_block_content_items($variables, 'hero');
}

/**
 * Implements hook_preprocess_block__DELTA__REGION().
 *
 * This made possible by our custom theme suggestion.
 *
 * @see ui_suite_uswds_theme_suggestions_block_alter()
 */
function ui_suite_uswds_preprocess_block__system_menu_block__footer_primary(&$variables) {
  _ui_suite_uswds_mark_menu_items($variables, 'footer_primary');
}

/**
 * Implements hook_preprocess_block__DELTA__REGION().
 *
 * This made possible by our custom theme suggestion.
 *
 * @see ui_suite_uswds_theme_suggestions_block_alter()
 */
function ui_suite_uswds_preprocess_block__system_menu_block__primary_menu(&$variables) {
  _ui_suite_uswds_mark_menu_items($variables, 'primary_menu');
}

/**
 * Implements hook_preprocess_block__DELTA__REGION().
 *
 * This made possible by our custom theme suggestion.
 *
 * @see ui_suite_uswds_theme_suggestions_block_alter()
 */
function ui_suite_uswds_preprocess_block__system_menu_block__secondary_menu(&$variables) {
  _ui_suite_uswds_mark_menu_items($variables, 'secondary_menu');
}

/**
 * Implements hook_preprocess_block__DELTA__REGION().
 *
 * This made possible by our custom theme suggestion.
 *
 * @see ui_suite_uswds_theme_suggestions_block_alter()
 */
function ui_suite_uswds_preprocess_block__system_menu_block__sidebar_first(&$variables) {
  _ui_suite_uswds_mark_menu_items($variables, 'sidebar_first');
}

/**
 * Implements hook_preprocess_block__DELTA__REGION().
 *
 * This made possible by our custom theme suggestion.
 *
 * @see ui_suite_uswds_theme_suggestions_block_alter()
 */
function ui_suite_uswds_preprocess_block__system_menu_block__sidebar_second(&$variables) {
  _ui_suite_uswds_mark_menu_items($variables, 'sidebar_second');
}

/**
 * Helper: mark block-content items as being in one of our block regions.
 *
 * This is the way we communicate a content block's region to its preprocessor
 * and template.
 *
 * @see preprocess/ui_suite_uswds_preprocess_block__block_content__*
 */
function _ui_suite_uswds_mark_block_content_items(&$variables, $region) {
  if (!empty($variables['content'])) {
    $variables['content']['#ui_suite_uswds_region'] = $region;
  }
}
