<?php

/**
 * @file
 * Hooks for forms.
 */

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;

/**
 * Implements hook_form_alter().
 */
function ui_suite_uswds_form_alter(&$form, FormStateInterface $form_state, $form_id) {
  ui_suite_uswds_attach_form_id($form, $form_id);
}

/**
 * Implements hook_theme_suggestions_HOOK_alter() for form templates.
 */
function ui_suite_uswds_theme_suggestions_form_alter(array &$suggestions, array $variables) {
  if ($variables['element']['#form_id'] === 'search_form') {
    $suggestions[] = 'form__search_block_form';
  }
}

/**
 * Attaches form id to all form elements.
 *
 * @param array $form
 *   The form or form element which children should have form id attached.
 * @param string $form_id
 *   The form id attached to form elements.
 */
function ui_suite_uswds_attach_form_id(array &$form, $form_id) {
  foreach (Element::children($form) as $child) {
    if (!isset($form[$child]['#form_id'])) {
      $form[$child]['#form_id'] = $form_id;
    }
    ui_suite_uswds_attach_form_id($form[$child], $form_id);
  }
}

/**
 * Implements hook_preprocess_form_element().
 */
function ui_suite_uswds_preprocess_form_element(&$variables) {
  // Add an element type for the label.
  $type = $variables['element']['#type'];
  $variables['label']['#element_type'] = $type;

  if (!empty($variables['errors'])) {
    $variables['attributes']['class'][] = 'usa-input-error';

    if (!empty($variables['element']['#id'])) {
      $variables['error_id'] = $variables['element']['#id'];
    }
    elseif (!empty($variables['element']['#attributes']['id'])) {
      $variables['error_id'] = $variables['element']['#attributes']['id'];
    }
  }
}

/**
 * Implements hook_preprocess_form_element_label().
 */
function ui_suite_uswds_preprocess_form_element_label(&$variables) {

  if (!empty($variables['element']['#element_type']) && $variables['element']['#element_type'] == 'checkbox') {
    $variables['is_checkbox'] = TRUE;
  }
  else {
    $variables['is_checkbox'] = FALSE;
  }

  if (!empty($variables['element']['#element_type']) && $variables['element']['#element_type'] == 'radio') {
    $variables['is_radio'] = TRUE;
  }
  else {
    $variables['is_radio'] = FALSE;
  }
}

/**
 * Implements hook_theme_suggestions_form_element().
 */
function ui_suite_uswds_theme_suggestions_form_element_alter(array &$suggestions, array $variables) {
  $suggestions = ['form_element__type__' . $variables['element']['#type']];
  if (isset($variables['element']['#form_id'])) {
    $suggestions[] = 'form_element__form_id__' . $variables['element']['#form_id'];
    $suggestions[] = 'form_element__' . $variables['element']['#form_id'] . '__' . $variables['element']['#type'];
  }

  return $suggestions;
}

/**
 * Implements hook_theme_suggestions_form_element_label().
 */
function ui_suite_uswds_theme_suggestions_form_element_label_alter(array &$suggestions, array $variables) {
  if (isset($variables['element']['#form_element_type'])) {
    $suggestions[] = 'form_element_label__form_type__' . $variables['element']['#form_element_type'];
  }
  if (isset($variables['element']['#form_id'])) {
    $suggestions[] = 'form_element_label__form_id__' . $variables['element']['#form_id'];
  }
  if (isset($variables['element']['#form_element_type']) && isset($variables['element']['#form_id'])) {
    $suggestions[] = 'form_element_label__' . $variables['element']['#form_id'] . '__' . $variables['element']['#form_element_type'];
  }

  if (isset($variables['element']['#element_type'])) {
    $suggestions[] = 'form_element_label__type__' . $variables['element']['#element_type'];
  }
  if (isset($variables['element']['#id'])) {
    $suggestions[] = 'form_element_label__id__' . str_replace('-', '_', $variables['element']['#id']);
  }
  if (isset($variables['element']['#element_type']) && isset($variables['element']['#id'])) {
    $suggestions[] = 'form_element_label__' . str_replace('-', '_', $variables['element']['#id']) . '__' . $variables['element']['#element_type'];
  }

  return $suggestions;
}

/**
 * Implements hook_theme_suggestions_input().
 */
function ui_suite_uswds_theme_suggestions_input_alter(array &$suggestions, array $variables) {
  if (in_array($variables['element']['#type'], ['checkbox', 'radio']) && $variables['element']['#attributes']['type'] !== 'hidden') {
    $suggestions[] = 'input__' . $variables['element']['#type'] . '__' . str_replace('-', '_', $variables['element']['#attributes']['id']);
  }

  return $suggestions;
}
