<?php

/**
 * @file
 * Utility code related to menus and menu blocks.
 */

/**
 * Implements hook_theme_suggestions_HOOK_alter().
 */
function ui_suite_uswds_theme_suggestions_menu_alter(array &$suggestions, array $variables) {
  if (!empty($variables['items'])) {
    foreach ($variables['items'] as $item) {
      if (!empty($item['#ui_suite_uswds_region'])) {
        if (_ui_suite_uswds_process_menu_region($item['#ui_suite_uswds_region'])) {
          $suggestions[] = 'menu__' . $item['#ui_suite_uswds_region'];
        }
      }
      // We only need to look at one.
      break;
    }
  }
  return $suggestions;
}

/**
 * Implements hook_preprocess_menu().
 */
function ui_suite_uswds_preprocess_menu(&$variables) {
  if (!empty($variables['items'])) {
    foreach ($variables['items'] as $item) {
      if (!empty($item['#ui_suite_uswds_region'])) {
        if (_ui_suite_uswds_process_menu_region($item['#ui_suite_uswds_region'])) {
          $variables['duplicate_parent'] = theme_get_setting('uswds_menu_accordion_duplicate_parent');
        }
      }
      // We only need to look at one.
      break;
    }
  }
  // Do we want to duplicate parent items as the first child?
}

/**
 * Implements hook_preprocess_menu__REGION().
 *
 * This made possible by our custom theme suggestion.
 *
 * @todo is this needed?
 *
 * @see ui_suite_uswds_theme_suggestions_block_alter()
 */
function ui_suite_uswds_preprocess_menu__mobile_menu(&$variables) {

  // Pass in uuids to help match accordion buttons with content.
  foreach ($variables['items'] as &$item) {
    $uuid = $item['original_link']->getDerivativeId();
    $item['uuid'] = $uuid;
  }
}

/**
 * Implements hook_preprocess_menu__REGION().
 *
 * This made possible by our custom theme suggestion.
 *
 * @see ui_suite_uswds_theme_suggestions_block_alter()
 */
function ui_suite_uswds_preprocess_menu__secondary_menu(&$variables) {

  if (\Drupal::moduleHandler()->moduleExists('search') && theme_get_setting('uswds_search')) {
    // If this is a basic header, we put the search form after the menu.
    if ('extended' == theme_get_setting('uswds_header_style')) {
      $search_item = t('<li class="js-search-button-container"><button type="submit" class="usa-header-search-button js-search-button">@search</button></li>', ['@search' => 'Search']);
      $variables['search_item'] = $search_item;
    }
  }
}

/**
 * Implements hook_preprocess_menu__REGION().
 *
 * This made possible by our custom theme suggestion.
 *
 * @see ui_suite_uswds_theme_suggestions_block_alter()
 */
function ui_suite_uswds_preprocess_menu__primary_menu(&$variables) {

  $variables['megamenu'] = theme_get_setting('uswds_header_mega');

  // Display 2nd level as column headers for 3rd - Megamenu.
  $variables['mega_display_second'] = theme_get_setting('uswds_header_mega_display_second');
}

/**
 * Implements hook_preprocess_menu_local_tasks().
 */
function ui_suite_uswds_preprocess_menu_local_tasks(&$variables) {
  if (!empty($variables['primary'])) {
    foreach ($variables['primary'] as $menu_item_key => $menu_attributes) {
      $variables['primary'][$menu_item_key]['#link']['localized_options']['attributes']['class'][] = 'usa-button';
      if (!empty($variables['primary'][$menu_item_key]['#active'])) {
        $variables['primary'][$menu_item_key]['#link']['localized_options']['attributes']['class'][] = 'usa-button--active';
      }
    }
  }
  if (!empty($variables['secondary'])) {
    foreach ($variables['secondary'] as $menu_item_key => $menu_attributes) {
      $variables['secondary'][$menu_item_key]['#link']['localized_options']['attributes']['class'][] = 'usa-button';
      $variables['secondary'][$menu_item_key]['#link']['localized_options']['attributes']['class'][] = 'usa-button-secondary';
      if (!empty($variables['secondary'][$menu_item_key]['#active'])) {
        $variables['secondary'][$menu_item_key]['#link']['localized_options']['attributes']['class'][] = 'usa-button--active';
      }
    }
  }
}

/**
 * Implements hook_preprocess_menu_local_action().
 */
function ui_suite_uswds_preprocess_menu_local_action(&$variables) {
  $variables['link']['#options']['attributes']['class'][] = 'usa-button';
  $variables['link']['#options']['attributes']['class'][] = 'usa-button-outline';
}

/**
 * Helper function to see if we should alter any menu.
 *
 * @param string $region
 *   The machine name of the region.
 *
 * @return bool
 *   Return if this should process the menu or not.
 */
function _ui_suite_uswds_process_menu_region($region) {
  $menu_bypass = theme_get_setting('uswds_menu_bypass');
  if (empty($menu_bypass)) {
    $menu_bypass = [];
  }
  return (empty($menu_bypass[$region]));
}

/**
 * Helper function to mark menu items as being in one of our menu regions.
 *
 * This is the way we communicate a menu block's region to its preprocessor
 * and template.
 *
 * @see preprocess/ui_suite_uswds_preprocess_block__system_menu_block__*
 */
function _ui_suite_uswds_mark_menu_items(&$variables, $region) {
  if (isset($variables['content']['#items'])) {
    foreach ($variables['content']['#items'] as &$item) {
      $item['#ui_suite_uswds_region'] = $region;
    }
  }
}
